# Welcome to earthinquiry


[![image](https://img.shields.io/pypi/v/earthinquiry.svg)](https://pypi.python.org/pypi/earthinquiry)


**A python package for customizing place-based geo-inquiry activities**


-   Free software: MIT License
-   Documentation: <https://asivitskis.github.io/earthinquiry>


## Features

-   TODO
